import { DocNodeKind } from './DocNode';
import { DocNodeLeaf, IDocNodeLeafParameters } from './DocNodeLeaf';
/**
 * Constructor parameters for {@link DocParticle}.
 */
export interface IDocParticleParameters extends IDocNodeLeafParameters {
    particleId: string;
    content: string;
    spacingAfterContent?: string | undefined;
}
/**
 * DocParticle is used to represent additional generic nodes that are part of the
 * DocNode tree, for the purpose of providing additional Excerpt information.
 *
 * @remarks
 * For example, a DocHtmlAttribute has a "=" delimiter and a quoted text string
 * that may be interesting to highlight in an editor; however, it would be awkward
 * to expect developers to construct these nodes as part of constructing a
 * DocHtmlAttribute object.  Instead, the developer merely assigns
 * DocHtmlAttribute.attributeValue, and the particle nodes automatically appear
 * in the tree as a byproduct.  And rather than introducing lots of special-purpose
 * types (e.g. DocHtmlAttributeEqualsDelimiter or DocHtmlAttributeStringValue),
 * they are represented as generic "DocParticle" nodes.
 */
export declare class DocParticle extends DocNodeLeaf {
    /** {@inheritDoc} */
    readonly kind: DocNodeKind;
    private _particleId;
    private _content;
    private _spacingAfterContent;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocParticleParameters);
    /**
     * A string identifier that uniquely identifies a particle among its siblings.
     * This can be used by DocNode.getChildren() visitors to determine what the particle
     * represents.
     */
    readonly particleId: string;
    /**
     * The text representation of this particle, excluding any surrounding whitespace.
     */
    readonly content: string;
    /**
     * Optional explicit whitespace that appears after the main content.
     * If undefined, then the renderer can use a formatting rule to generate appropriate spacing.
     */
    readonly spacingAfterContent: string | undefined;
    /** @override */
    updateParameters(parameters: IDocParticleParameters): void;
}
